summaryrefslogtreecommitdiff
path: root/desktop/src/onionshare/widgets.py
diff options
context:
space:
mode:
Diffstat (limited to 'desktop/src/onionshare/widgets.py')
-rw-r--r--desktop/src/onionshare/widgets.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/desktop/src/onionshare/widgets.py b/desktop/src/onionshare/widgets.py
index a1880a2e..c239d03a 100644
--- a/desktop/src/onionshare/widgets.py
+++ b/desktop/src/onionshare/widgets.py
@@ -84,14 +84,15 @@ class AddFileDialog(QtWidgets.QFileDialog):
QtWidgets.QDialog.accept(self)
-class MinimumWidthWidget(QtWidgets.QWidget):
+class MinimumSizeWidget(QtWidgets.QWidget):
"""
An empty widget with a minimum width, just to force layouts to behave
"""
- def __init__(self, width):
- super(MinimumWidthWidget, self).__init__()
+ def __init__(self, width, height):
+ super(MinimumSizeWidget, self).__init__()
self.setMinimumWidth(width)
+ self.setMinimumHeight(height)
class Image(qrcode.image.base.BaseImage):
@@ -84,14 +84,15 @@ class AddFileDialog(QtWidgets.QFileDialog):
"""
- An empty widget with a minimum width, just to force layouts to behave
+ An empty widget with a minimum width and height, just to force layouts to behave
"""